Twitter. It's what's happening.
Description: From breaking news and entertainment to sports and politics, get the full story with all the live commentary.

Skip to content
Forgot password?
Log in

# See what’s happening in the world right now

## Join Twitter today.

Sign up Log in
Follow your interests.
Hear what people are talking about.
Join the conversation.

### Twitter.com makes heavy use of browser cookies

Please enable cookies in your browser preferences before signing in.

- About
- Help Center
- Blog
- Status
- Jobs
- Terms
- Privacy Policy
- Cookies
- Ads info
- Brand
- Apps
- Advertise
- Marketing
- Businesses
- Developers
- Directory
- Settings
- © 2020 Twitter

Dismiss
Previous
Next

### Go to a person's profile

### Promote this Tweet

### Block

- ## Tweet with a location

  You can add location information to your Tweets, such as your city or precise location, from the web and via third-party applications. You always have the option to delete your Tweet location history. Learn more

### Your lists

### Create a new list

List name

Description Under 100 characters, optional

Privacy
Public · Anyone can follow this list Private · Only you can access this list

###

### Copy link to Tweet

Here's the URL for this Tweet. Copy it to easily share with friends.

### Embed this Tweet

### Embed this Video

Add this Tweet to your website by copying the code below. Learn more

Add this video to your website by copying the code below. Learn more

Hmm, there was a problem reaching the server.

Include parent Tweet
Include media

By embedding Twitter content in your website or app, you are agreeing to the Twitter Developer Agreement and Developer Policy.

### Preview

### Why you're seeing this ad

### Log in to Twitter

Remember me · Forgot password?

### Sign up for Twitter

## Not on Twitter? Sign up, tune into the things you care about, and get updates as they happen.

Sign up

### Two-way (sending and receiving) short codes:

Country | Code | For customers of
--- | --- | ---
United States | 40404 | (any)
Canada | 21212 | (any)
United Kingdom | 86444 | Vodafone, Orange, 3, O2
Brazil | 40404 | Nextel, TIM
Haiti | 40404 | Digicel, Voila
Ireland | 51210 | Vodafone, O2
India | 53000 | Bharti Airtel, Videocon, Reliance
Indonesia | 89887 | AXIS, 3, Telkomsel, Indosat, XL Axiata
Italy | 4880804 | Wind
3424486444 | Vodafone
» See SMS short codes for other countries

### Confirmation

###

### Welcome home!

This timeline is where you’ll spend most of your time, getting instant updates about what matters to you.

### Tweets not working for you?

Hover over the profile pic and click the Following button to unfollow any account.

### Say a lot with a little

When you see a Tweet you love, tap the heart — it lets the person who wrote it know you shared the love.

### Spread the word

The fastest way to share someone else’s Tweet with your followers is with a Retweet. Tap the icon to send it instantly.

### Join the conversation

Add your thoughts about any Tweet with a Reply. Find a topic you’re passionate about, and jump right in.

### Learn the latest

Get instant insight into what people are talking about now.

### Get more of what you love

Follow more accounts to get instant updates about topics you care about.

### Find what's happening

See the latest conversations about any topic instantly.

### Never miss a Moment

Catch up instantly on the best stories happening as they unfold.